@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 26 Aug 2008 07:50:00 JST
+ *  Last-modified: Fri 05 Sep 2008 13:26:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_TOKENMAP_H
@@ -90,7 +90,8 @@ namespace clx {
 				key_type key = lexical_cast<key_type>(tmp);
 				value_type val = lexical_cast<value_type>(token);
 				this->insert(std::pair<key_type, value_type>(key, val));
-				if (first++ == last) break;
+				if (first == last) break;
+				++first;
 			}
 			return *this;
 		}
